@@ -375,25 +375,16 @@ def nested_distributed_piecewise_alignment_pipeline(
     mov,
     fix_spacing,
     mov_spacing,
-    block_schedule,
-    parameter_schedule=None,
-    initial_transform_list=None,
+    schedule,
+    static_transform_list=None,
     fix_mask=None,
     mov_mask=None,
-    intermediates_path=None,
     cluster=None,
     cluster_kwargs={},
     **kwargs,
 ):
     """
-    Nested piecewise affine alignments.
-    Two levels of nesting: outer levels and inner levels.
-    Transforms are averaged over inner levels and composed
-    across outer levels. See the `block_schedule` parameter
-    for more details.
-
-    This method is good at capturing large bends and twists that
-    cannot be captured with global rigid and affine alignment.
+    Compose multiple calls to distributed_piecewise_alignment_pipeline with one function call.
 
     Parameters
     ----------
@@ -401,7 +392,7 @@ def nested_distributed_piecewise_alignment_pipeline(
         the fixed image
 
     mov : ndarray
-        the moving image; if `initial_transform_list` is None then
+        the moving image; if `static_transform_list` is None then
         `fix.shape` must equal `mov.shape`
 
     fix_spacing : 1d array
@@ -414,60 +405,36 @@ def nested_distributed_piecewise_alignment_pipeline(
         of the moving image.
         Length must equal `mov.ndim`
 
-    block_schedule : list of lists of tuples of ints.
-        Block structure for outer and inner levels.
-        Tuples must all be of length `fix.ndim`
+    schedule : list of tuples in this form [(tuple, [(str, dict), (str, dict), ...]), ...]
+        The blocksize and steps arguments for each call to distributed_piecewise_alignment_pipeline
+        An example:
+            step1 = ( (3, 1, 1), [('affine', affine_kwargs)] )
+            step2 = ( (
 
-        Example:
-            [ [(2, 1, 1), (1, 2, 1),],
-              [(3, 1, 1), (1, 1, 2),],
-              [(4, 1, 1), (2, 2, 1), (2, 2, 2),], ]
 
-            This block schedule specifies three outer levels:
-            1) This outer level contains two inner levels:
-                1.1) Piecewise rigid+affine with 2 blocks along first axis
-                1.2) Piecewise rigid+affine with 2 blocks along second axis
-            2) This outer level contains two inner levels:
-                2.1) Piecewise rigid+affine with 3 blocks along first axis
-                2.2) Piecewise rigid+affine with 2 blocks along third axis
-            3) This outer level contains three inner levels:
-                3.1) Piecewise rigid+affine with 4 blocks along first axis
-                3.2) Piecewise rigid+affine with 4 blocks total: the first
-                     and second axis are each cut into 2 blocks
-                3.3) Piecewise rigid+affine with 8 blocks total: all axes
-                     are cut into 2 blocks
-
-            1.1 and 1.2 are computed (serially) then averaged. This result
-            is stored. 2.1 and 2.2 are computed (serially) then averaged.
-            This is then composed with the result from the first level.
-            This process proceeds for as many levels that are specified.
-
-            Each instance of a piecewise rigid+affine alignment is handled
-            by `distributed_piecewise_affine_alignment` and is therefore
-            parallelized over blocks on distributed hardware.
-
-    parameter_schedule : list of type dict (default: None)
-        Overrides the general parameter `distributed_piecewise_affine_align`
-        parameter settings for individual instances. Length of the list
-        (total number of dictionaries) must equal the total number of
-        tuples in `block_schedule`.
-
-    initial_transform_list : list of ndarrays (default: None)
-        A list of transforms to apply to the moving image before running
-        twist alignment. If `fix.shape` does not equal `mov.shape`
-        then an `initial_transform_list` must be given.
+    static_transform_list : list of numpy arrays (default: [])
+        Transforms applied to moving image before applying query transform
+        Assumed to have the same domain as the fixed image, though sampling
+        can be different. I.e. the origin and span are the same (in physical
+        units) but the number of voxels can be different.
 
     fix_mask : binary ndarray (default: None)
         A mask limiting metric evaluation region of the fixed image
+        Assumed to have the same domain as the fixed image, though sampling
+        can be different. I.e. the origin and span are the same (in physical
+        units) but the number of voxels can be different.
 
     mov_mask : binary ndarray (default: None)
         A mask limiting metric evaluation region of the moving image
-
-    intermediates_path : string (default: None)
-        Path to folder where intermediate results are written.
-        The deform, transformed moving image, and transformed
-        moving image mask (if given) are stored on disk as npy files.
+        Assumed to have the same domain as the moving image, though sampling
+        can be different. I.e. the origin and span are the same (in physical
+        units) but the number of voxels can be different.
     
+    cluster : ClusterWrap.cluster object (default: None)
+        Only set if you have constructed your own static cluster. The default behavior
+        is to construct a cluster for the duration of this function, then close it
+        when the function is finished.
+
     cluster_kwargs : dict (default: {})
         Arguments passed to ClusterWrap.cluster
         If working with an LSF cluster, this will be
@@ -476,27 +443,53 @@ def nested_distributed_piecewise_alignment_pipeline(
         This is how distribution parameters are specified.
 
     kwargs : any additional arguments
-        Passed to `distributed_piecewise_affine_align`
+        Passed to `distributed_piecewise_alignment_pipeline`
 
     Returns
     -------
     field : ndarray
-        Composition of all outer level transforms. A displacement vector
-        field of the shape `fix.shape` + (3,) where the last dimension
-        is the vector dimension.
     """
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+def old()
+
     # set working copies of moving data
-    if initial_transform_list is not None:
+    if static_transform_list is not None:
         current_moving = apply_transform(
             fix, mov, fix_spacing, mov_spacing,
-            transform_list=initial_transform_list,
+            transform_list=static_transform_list,
         )
         current_moving_mask = None
         if mov_mask is not None:
             current_moving_mask = apply_transform(
                 fix, mov_mask, fix_spacing, mov_spacing,
-                transform_list=initial_transform_list,
+                transform_list=static_transform_list,
             )
             current_moving_mask = (current_moving_mask > 0).astype(np.uint8)
     else:
@@ -543,8 +536,8 @@ def nested_distributed_piecewise_alignment_pipeline(
             deform = ddd
 
         # combine with initial transforms if given
-        if initial_transform_list is not None:
-            transform_list = initial_transform_list + [deform,]
+        if static_transform_list is not None:
+            transform_list = static_transform_list + [deform,]
         else:
             transform_list = [deform,]
 
